package qiniu.titan_plugin;

import android.content.Context;
import android.util.Log;

import java.util.ArrayList;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import vip.z4k.android.sdk.TitanSDKCore;

/**
 * TitanPlugin
 */
public class TitanPlugin implements FlutterPlugin, MethodCallHandler {
    private static final String TAG = "TitanPlugin";
    private static volatile Context ctx;
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "titan_plugin");
        channel.setMethodCallHandler(new TitanPlugin());
    }

    @Override
    public void onAttachedToEngine(FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "titan_plugin");
        channel.setMethodCallHandler(this);
        ctx = flutterPluginBinding.getApplicationContext();
    }

    private String handle(MethodCall call) {
        if (call == null || call.method == null) {
            return null;
        }
        String ret = "";
        String methodName = call.method;
        switch (methodName) {
            case "start":
                Log.i(TAG, "handle: app start " + ctx);
                TitanSDKCore.start(ctx);
                break;
            case "stop":
                Log.i(TAG, "handle: app stop ");
                TitanSDKCore.stop();
                break;
            case "setToken":
                ArrayList<Object> s = call.arguments();
                Object t = s.get(0);
                int v = 0;
                if (t instanceof Long) {
                    v = ((Long) t).intValue();
                } else if (t instanceof Integer){
                    v = (Integer) t;
                } else {
                    Log.i(TAG, "handle: setToken error ");
                    ret = null;
                }
                Log.i(TAG, "handle: setToken");
                TitanSDKCore.setToken(v);
                break;
            case "setListenPort":
                ArrayList<Integer> spt = call.arguments();
                Integer port = spt.get(0);
                Log.i(TAG, "handle: setListenPort " + port);
                TitanSDKCore.setListenPort(port);
                break;
            case "setPauseTimeout":
                ArrayList<Integer> sp = call.arguments();
                Integer p = sp.get(0);
                Log.i(TAG, "handle: setPauseTimeout " + p);
                TitanSDKCore.setPauseTimeout(p);
                break;
            case "setSleepTimeout":
                ArrayList<Integer> st = call.arguments();
                Integer sl = st.get(0);
                Log.i(TAG, "handle: setSleepTimeout " + sl);
                TitanSDKCore.setSleepTimeout(sl);
                break;
            case "addHttpHeaderBypassKey":
                ArrayList<String> ss = call.arguments();
                String h = ss.get(0);
                Log.i(TAG, "handle: addHttpHeaderBypassKey " + h);
                TitanSDKCore.addHttpHeaderBypassKey(h);
                break;
            case "getVodUrl":
                ArrayList<String> sv = call.arguments();
                String iv = sv.get(0);
                String jv = sv.get(1);
                ret = TitanSDKCore.getVodUrl(iv, jv);
                Log.i(TAG, "handle: getVodUrl ret " + ret);
                break;
            case "getDownloadUrl":
                ArrayList<String> sd = call.arguments();
                String id = sd.get(0);
                String jd = sd.get(1);
                ret = TitanSDKCore.getDownloadUrl(id, jd);
                Log.i(TAG, "handle: getDownloadUrl ret " + ret);
                break;
            default:
                Log.i(TAG, "handle: Not implement " + methodName);
                ret = null;
        }
        return ret;
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        String ret = handle(call);
        if (ret != null) {
            result.success(ret);
        } else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}
