import 'dart:async';

import 'package:flutter/services.dart';

class TitanPlugin {
  static const MethodChannel _channel = const MethodChannel('titan_plugin');

  /// Set the unique custom token for use the SDK.
  ///
  /// You need require a token from support before usage.
  ///
  static set token(int token) {
    _channel.invokeMethod("setToken", [token]);
  }

  /// Set the unique custom token for use the SDK.
  ///
  /// You need require a token from support before usage.
  ///
  static set listenPort(int port) {
    _channel.invokeMethod("setListenPort", [port]);
  }

  /// Set pause timeout for sdk. unit ms.
  ///
  /// If receive none for a period, the sdk would pause for a while.
  ///
  static set pauseTimeout(int timeout) {
    _channel.invokeMethod("setPauseTimeout", [timeout]);
  }

  /// Set sleep timeout for sdk. unit ms.
  ///
  /// If receive none for a period, the sdk would sleep for a while.
  ///
  static set sleepTimeout(int timeout) {
    _channel.invokeMethod("setSleepTimeout", [timeout]);
  }

  /// Set key words http return back.
  ///
  static void addHttpHeaderBypassKey(String key) {
    _channel.invokeMethod("addHttpHeaderBypassKey", [key]);
  }

  /// Get vod url from the normal http url.
  ///
  /// options is json string
  static Future<String> getVodUrl(String url, String option) async {
    final String ret = await _channel.invokeMethod('getVodUrl', [url, option]);
    return ret;
  }

  /// Get download url from the normal http url.
  ///
  /// options is json string
  static Future<String> getDownloadUrl(String url, String option) async {
    final String ret =
        await _channel.invokeMethod('getDownloadUrl', [url, option]);
    return ret;
  }

  /// Start sdk.
  ///
  static void start() async {
    await _channel.invokeMethod("start");
  }

  /// Stop sdk.
  ///
  static void stop() async {
    await _channel.invokeMethod("stop");
  }
}
